import React, { useEffect, useState } from "react";
import axios from "axios";
import Header from "./Header";
import Card from "./Card";

const Main = ({ userData }) => {

    const [films, setFilms] = useState([]);
    const [gits, setGits] = useState([]);
    const [museum, setMuseum] = useState([]);

    const optionsFilms = {
        method: 'GET',
        url: `https://easytravel.zetcraft.ru/v1/GetAllFilmsInCity/${userData.selectedCity}`,
    };

    const optionsGis = {
        method: 'GET',
        url: `https://easytravel.zetcraft.ru/v1/GetAllGuides/${userData.selectedCity}`,
    };

    const optionsMuseum = {
        method: 'GET',
        url: `https://easytravel.zetcraft.ru/v1/GetAllMuseum/${userData.selectedCity}`,
    };

    useEffect(() => {
        axios.request(optionsFilms).then(function (response) {
            setFilms(response.data);
        }).catch(function (error) {
            console.error(error);
        });
    }, []);

    useEffect(() => {
        axios.request(optionsGis).then(function (response) {
            setGits(response.data);
        }).catch(function (error) {
            console.error(error);
        });
    }, []);

    useEffect(() => {
        axios.request(optionsMuseum).then(function (response) {
            setMuseum(response.data);
        }).catch(function (error) {
            console.error(error);
        });
    }, []);

    console.log(userData.unique);

    return (
        <div>
        <Header />
        <Card city={userData.selectedCity}/>
        <div style={{
            overflow: 'hidden',
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
        }}>
            <h2>Кино по пушкинской карте</h2>
            <div style={{
                width: '100%',
                overflowX: 'auto',
                display: 'flex',
                justifyContent: 'center',
            }}>
                <ul style={{
                    display: 'flex',
                    listStyle: 'none',
                    padding: 0,
                }}>
                    {films.map((film, index) => (
                        <li key={index} style={{
                            marginRight: '10px',
                        }}>
                            <div key={index} style={{
                                height: 200,
                                width: 140,
                                display: 'flex',
                                alignContent: 'center',
                                flexDirection: 'column',
                            }}>
                            <div style={{
                                display: 'flex',
                                flexDirection: 'column',
                                alignItems: 'center',
                            }}>
                                <img src={film.imageURL} alt="#" style={{
                                    height: 110,
                                    width: 79,
                                }}/>
                                {film.filmName}
                            </div>
                        </div>
                    </li>
                ))}
            </ul>
            </div>

            <h2>Тур. гиды г.{userData.selectedCity}</h2>
            <ul>
                {gits.map((guide, index) => (
                    <li key={index}>{guide.name}</li>
                ))}
            </ul>

            <h2>Музеи г.{userData.selectedCity}</h2>
            <ul>
                {museum.map((museumItem, index) => (
                    <li key={index}>{museumItem.name}</li>
                ))}
            </ul>
        </div>
        </div>
    );
}

export default Main;
